@@ -1,6 +1,7 @@
-/* Copyright (c) 1997-2018
-   Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-   http://www.polymake.org
+/* Copyright (c) 1997-2020
+   Ewgenij Gawrilow, Michael Joswig, and the polymake team
+   Technische Universität Berlin, Germany
+   https://polymake.org
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -20,13 +21,13 @@
 
 namespace polymake { namespace topaz {
   
-perl::Object klein_bottle()
+BigObject klein_bottle()
 {
-   perl::Object p("SimplicialComplex");
+   BigObject p("SimplicialComplex");
    p.set_description() << "The Klein bottle.\n";
 
-   const Array< Set<int> > PJP = real_projective_plane_facets();
-   const std::list< Set<int> > C = connected_sum(PJP,PJP);
+   const Array<Set<Int>> PJP = real_projective_plane_facets();
+   const std::list<Set<Int>> C = connected_sum(PJP,PJP);
    
    p.take("FACETS") << C;
    p.take("DIM") << 2;
